var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/apollo.ts
import { H } from "@highlight-run/node";
var ApolloServerHighlightPlugin = function(options) {
  return {
    requestDidStart(req) {
      return __async(this, null, function* () {
        var _a2, _b;
        if (!H.isInitialized()) {
          H.init(options);
          H._debug("initialized H in apollo server");
        }
        const headers = {};
        (_b = (_a2 = req.request.http) == null ? void 0 : _a2.headers) == null ? void 0 : _b.forEach((k, v) => headers[k] = v);
        const { secureSessionId, requestId } = H.parseHeaders(headers);
        H._debug("processError", "extracted from headers", {
          secureSessionId,
          requestId
        });
        H.setHeaders({ secureSessionId, requestId });
        return {
          didEncounterErrors(requestContext) {
            return __async(this, null, function* () {
              for (const error of requestContext.errors) {
                H.consumeError(error, secureSessionId, requestId);
                H._debug("consumed apollo request error", error);
              }
            });
          }
        };
      });
    }
  };
};

// src/apolloV3.ts
import { H as H2 } from "@highlight-run/node";
var ApolloServerV3HighlightPlugin = function(options) {
  return {
    requestDidStart(req) {
      return __async(this, null, function* () {
        var _a2, _b;
        if (!H2.isInitialized()) {
          H2.init(options);
          H2._debug("initialized H in apollo server");
        }
        const headers = {};
        for (const [k, v] of (_b = (_a2 = req.request.http) == null ? void 0 : _a2.headers) != null ? _b : []) {
          headers[k] = v;
        }
        const { secureSessionId, requestId } = H2.parseHeaders(headers);
        H2._debug("processError", "extracted from headers", {
          secureSessionId,
          requestId
        });
        H2.setHeaders({ secureSessionId, requestId });
        return {
          didEncounterErrors(requestContext) {
            return __async(this, null, function* () {
              for (const error of requestContext.errors) {
                H2.consumeError(error, secureSessionId, requestId);
                H2._debug("consumed apollo request error", error);
              }
            });
          }
        };
      });
    }
  };
};
export {
  ApolloServerHighlightPlugin,
  ApolloServerV3HighlightPlugin
};
